==> ardour_2.0.5.orig.tar.gz: ardour-2.0.5/gtk2_ardour/canvas_vars.h <==
CANVAS_VARIABLE(canvasvar_WaveForm, "waveform")
CANVAS_VARIABLE(canvasvar_WaveFormClip, "clipped waveform")
CANVAS_VARIABLE(canvasvar_FrameBase, "region base")
CANVAS_VARIABLE(canvasvar_SelectedFrameBase, "selected region base")
CANVAS_VARIABLE(canvasvar_AudioTrackBase, "audio track base")
CANVAS_VARIABLE(canvasvar_AudioBusBase, "audio bus base")
CANVAS_VARIABLE(canvasvar_MidiTrackBase, "midi track base")
CANVAS_VARIABLE(canvasvar_MidiBusBase, "midi bus base")
CANVAS_VARIABLE(canvasvar_TimeStretchFill, "time-stretch-fill")
CANVAS_VARIABLE(canvasvar_TimeStretchOutline, "time-stretch-outline")
CANVAS_VARIABLE(canvasvar_AutomationLine, "automation line")
CANVAS_VARIABLE(canvasvar_RedirectAutomationLine, "processor automation line")
CANVAS_VARIABLE(canvasvar_ControlPointFill, "control point fill")
CANVAS_VARIABLE(canvasvar_ControlPointOutline, "control point outline")
CANVAS_VARIABLE(canvasvar_EnteredControlPointOutline, "entered control point outline")
CANVAS_VARIABLE(canvasvar_EnteredControlPointSelected, "entered control point selected")
CANVAS_VARIABLE(canvasvar_EnteredControlPoint, "entered control point")
CANVAS_VARIABLE(canvasvar_ControlPointSelected, "control point selected")
CANVAS_VARIABLE(canvasvar_ControlPoint, "control point")
CANVAS_VARIABLE(canvasvar_AutomationTrackFill, "automation track fill")
CANVAS_VARIABLE(canvasvar_AutomationTrackOutline, "automation track outline")
CANVAS_VARIABLE(canvasvar_CrossfadeEditorBase, "crossfade editor base")
CANVAS_VARIABLE(canvasvar_CrossfadeEditorLine, "crossfade editor line")
CANVAS_VARIABLE(canvasvar_SelectedCrossfadeEditorLine, "selected crossfade editor line")
CANVAS_VARIABLE(canvasvar_CrossfadeEditorLineShading, "crossfade editor line shading")
CANVAS_VARIABLE(canvasvar_CrossfadeEditorPointFill, "crossfade editor point fill")
CANVAS_VARIABLE(canvasvar_CrossfadeEditorPointOutline, "crossfade editor point outline")
CANVAS_VARIABLE(canvasvar_CrossfadeEditorWave, "crossfade editor wave")
CANVAS_VARIABLE(canvasvar_SelectedCrossfadeEditorWave, "selected crossfade editor wave")
CANVAS_VARIABLE(canvasvar_CrossfadeLine, "crossfade line")
CANVAS_VARIABLE(canvasvar_ActiveCrossfade, "active crossfade")
CANVAS_VARIABLE(canvasvar_InactiveCrossfade, "inactive crossfade")
CANVAS_VARIABLE(canvasvar_LocationMarker, "location marker")
CANVAS_VARIABLE(canvasvar_LocationRange, "location range")
CANVAS_VARIABLE(canvasvar_LocationCDMarker, "location cd marker")
CANVAS_VARIABLE(canvasvar_LocationLoop, "location loop")
CANVAS_VARIABLE(canvasvar_LocationPunch, "location punch")
CANVAS_VARIABLE(canvasvar_VerboseCanvasCursor, "verbose canvas cursor")
CANVAS_VARIABLE(canvasvar_MarkerLabel, "marker label")
CANVAS_VARIABLE(canvasvar_MarkerBarSeparator, "marker bar separator")
CANVAS_VARIABLE(canvasvar_TempoBar, "tempo bar")
CANVAS_VARIABLE(canvasvar_MeterBar, "meterbar")
CANVAS_VARIABLE(canvasvar_MarkerBar, "markerbar")
CANVAS_VARIABLE(canvasvar_RangeMarkerBar, "rangemarker bar")
CANVAS_VARIABLE(canvasvar_TransportMarkerBar, "TransportMarkerBar")
CANVAS_VARIABLE(canvasvar_RangeDragBarRect, "RangeDragBarRect")
CANVAS_VARIABLE(canvasvar_RangeDragRect, "RangeDragRect")
CANVAS_VARIABLE(canvasvar_TransportDragRect, "TransportDragRect")
CANVAS_VARIABLE(canvasvar_MarkerDragLine, "MarkerDragLine")
CANVAS_VARIABLE(canvasvar_TransportLoopRect, "TransportLoopRect")
CANVAS_VARIABLE(canvasvar_TransportPunchRect, "TransportPunchRect")
CANVAS_VARIABLE(canvasvar_PunchLine, "PunchLine")
CANVAS_VARIABLE(canvasvar_ZoomRect, "ZoomRect")
CANVAS_VARIABLE(canvasvar_RubberBandRect, "RubberBandRect")
CANVAS_VARIABLE(canvasvar_EnteredGainLine, "EnteredGainLine")
CANVAS_VARIABLE(canvasvar_EnteredAutomationLine, "EnteredAutomationLine")
CANVAS_VARIABLE(canvasvar_EnteredMarker, "EnteredMarker")
CANVAS_VARIABLE(canvasvar_MeterMarker, "MeterMarker")
CANVAS_VARIABLE(canvasvar_TempoMarker, "TempoMarker")
CANVAS_VARIABLE(canvasvar_MeasureLineBeat, "MeasureLineBeat")
CANVAS_VARIABLE(canvasvar_MeasureLineBar, "MeasureLineBar")
CANVAS_VARIABLE(canvasvar_GhostTrackBase, "GhostTrackBase")
CANVAS_VARIABLE(canvasvar_GhostTrackWave, "GhostTrackWave")
CANVAS_VARIABLE(canvasvar_GhostTrackWaveClip, "GhostTrackWaveClip")
CANVAS_VARIABLE(canvasvar_GhostTrackZeroLine, "GhostTrackZeroLine")
CANVAS_VARIABLE(canvasvar_ImageTrack, "ImageTrack")
CANVAS_VARIABLE(canvasvar_MarkerTrack, "MarkerTrack")
CANVAS_VARIABLE(canvasvar_ZeroLine, "ZeroLine")
CANVAS_VARIABLE(canvasvar_GainLine, "GainLine")
CANVAS_VARIABLE(canvasvar_GainLineInactive, "GainLineInactive")
CANVAS_VARIABLE(canvasvar_RecordingRect, "RecordingRect")
CANVAS_VARIABLE(canvasvar_SelectionRect, "SelectionRect")
CANVAS_VARIABLE(canvasvar_Selection, "Selection")
CANVAS_VARIABLE(canvasvar_VestigialFrame, "VestigialFrame")
CANVAS_VARIABLE(canvasvar_TimeAxisFrame, "TimeAxisFrame")
CANVAS_VARIABLE(canvasvar_NameHighlightFill, "NameHighlightFill")
CANVAS_VARIABLE(canvasvar_NameHighlightOutline, "NameHighlightOutline")
CANVAS_VARIABLE(canvasvar_FrameHandle, "FrameHandle")
CANVAS_VARIABLE(canvasvar_TrimHandleLocked, "TrimHandleLocked")
CANVAS_VARIABLE(canvasvar_TrimHandle, "TrimHandle")
CANVAS_VARIABLE(canvasvar_EditCursor, "EditCursor")
CANVAS_VARIABLE(canvasvar_PlayHead, "PlayHead")

==> ardour_2.3.1.orig.tar.gz: ardour-2.3/gtk2_ardour/canvas_vars.h <==
CANVAS_VARIABLE(canvasvar_ActiveCrossfade, "active crossfade")
CANVAS_VARIABLE(canvasvar_AudioBusBase, "audio bus base")
CANVAS_VARIABLE(canvasvar_AudioTrackBase, "audio track base")
CANVAS_VARIABLE(canvasvar_AutomationLine, "automation line")
CANVAS_VARIABLE(canvasvar_AutomationTrackFill, "automation track fill")
CANVAS_VARIABLE(canvasvar_AutomationTrackOutline, "automation track outline")
CANVAS_VARIABLE(canvasvar_CDMarkerBar, "cdmarkerbar")
CANVAS_VARIABLE(canvasvar_ControlPoint, "control point")
CANVAS_VARIABLE(canvasvar_ControlPointFill, "control point fill")
CANVAS_VARIABLE(canvasvar_ControlPointOutline, "control point outline")
CANVAS_VARIABLE(canvasvar_ControlPointSelected, "control point selected")
CANVAS_VARIABLE(canvasvar_CrossfadeEditorBase, "crossfade editor base")
CANVAS_VARIABLE(canvasvar_CrossfadeEditorLine, "crossfade editor line")
CANVAS_VARIABLE(canvasvar_CrossfadeEditorLineShading, "crossfade editor line shading")
CANVAS_VARIABLE(canvasvar_CrossfadeEditorPointFill, "crossfade editor point fill")
CANVAS_VARIABLE(canvasvar_CrossfadeEditorPointOutline, "crossfade editor point outline")
CANVAS_VARIABLE(canvasvar_CrossfadeEditorWave, "crossfade editor wave")
CANVAS_VARIABLE(canvasvar_CrossfadeLine, "crossfade line")
CANVAS_VARIABLE(canvasvar_EditPoint, "EditPoint")
CANVAS_VARIABLE(canvasvar_EnteredAutomationLine, "EnteredAutomationLine")
CANVAS_VARIABLE(canvasvar_EnteredControlPoint, "entered control point")
CANVAS_VARIABLE(canvasvar_EnteredControlPointOutline, "entered control point outline")
CANVAS_VARIABLE(canvasvar_EnteredControlPointSelected, "entered control point selected")
CANVAS_VARIABLE(canvasvar_EnteredGainLine, "EnteredGainLine")
CANVAS_VARIABLE(canvasvar_EnteredMarker, "EnteredMarker")
CANVAS_VARIABLE(canvasvar_FrameBase, "region base")
CANVAS_VARIABLE(canvasvar_FrameHandle, "FrameHandle")
CANVAS_VARIABLE(canvasvar_GainLine, "GainLine")
CANVAS_VARIABLE(canvasvar_GainLineInactive, "GainLineInactive")
CANVAS_VARIABLE(canvasvar_GhostTrackBase, "GhostTrackBase")
CANVAS_VARIABLE(canvasvar_GhostTrackWaveClip, "GhostTrackWaveClip")
CANVAS_VARIABLE(canvasvar_GhostTrackWave, "GhostTrackWave")
CANVAS_VARIABLE(canvasvar_GhostTrackZeroLine, "GhostTrackZeroLine")
CANVAS_VARIABLE(canvasvar_ImageTrack, "ImageTrack")
CANVAS_VARIABLE(canvasvar_InactiveCrossfade, "inactive crossfade")
CANVAS_VARIABLE(canvasvar_LocationCDMarker, "location cd marker")
CANVAS_VARIABLE(canvasvar_LocationLoop, "location loop")
CANVAS_VARIABLE(canvasvar_LocationMarker, "location marker")
CANVAS_VARIABLE(canvasvar_LocationPunch, "location punch")
CANVAS_VARIABLE(canvasvar_LocationRange, "location range")
CANVAS_VARIABLE(canvasvar_MarkerBar, "markerbar")
CANVAS_VARIABLE(canvasvar_MarkerBarSeparator, "marker bar separator")
CANVAS_VARIABLE(canvasvar_MarkerDragLine, "MarkerDragLine")
CANVAS_VARIABLE(canvasvar_MarkerLabel, "marker label")
CANVAS_VARIABLE(canvasvar_MarkerTrack, "MarkerTrack")
CANVAS_VARIABLE(canvasvar_MeasureLineBar, "MeasureLineBar")
CANVAS_VARIABLE(canvasvar_MeasureLineBeat, "MeasureLineBeat")
CANVAS_VARIABLE(canvasvar_MeterBar, "meterbar")
CANVAS_VARIABLE(canvasvar_MeterColorBase, "MeterColorBase")
CANVAS_VARIABLE(canvasvar_MeterColorClip, "MeterColorClip")
CANVAS_VARIABLE(canvasvar_MeterColorMid, "MeterColorMid")
CANVAS_VARIABLE(canvasvar_MeterColorTop, "MeterColorTop")
CANVAS_VARIABLE(canvasvar_MeterMarker, "MeterMarker")
CANVAS_VARIABLE(canvasvar_MidiBusBase, "midi bus base")
CANVAS_VARIABLE(canvasvar_MidiTrackBase, "midi track base")
CANVAS_VARIABLE(canvasvar_NameHighlightFill, "NameHighlightFill")
CANVAS_VARIABLE(canvasvar_NameHighlightOutline, "NameHighlightOutline")
CANVAS_VARIABLE(canvasvar_PlayHead, "PlayHead")
CANVAS_VARIABLE(canvasvar_PunchLine, "PunchLine")
CANVAS_VARIABLE(canvasvar_RangeDragBarRect, "RangeDragBarRect")
CANVAS_VARIABLE(canvasvar_RangeDragRect, "RangeDragRect")
CANVAS_VARIABLE(canvasvar_RangeMarkerBar, "rangemarker bar")
CANVAS_VARIABLE(canvasvar_RecordingRect, "RecordingRect")
CANVAS_VARIABLE(canvasvar_RedirectAutomationLine, "processor automation line")
CANVAS_VARIABLE(canvasvar_RubberBandRect, "RubberBandRect")
CANVAS_VARIABLE(canvasvar_SelectedCrossfadeEditorLine, "selected crossfade editor line")
CANVAS_VARIABLE(canvasvar_SelectedCrossfadeEditorWave, "selected crossfade editor wave")
CANVAS_VARIABLE(canvasvar_SelectedFrameBase, "selected region base")
CANVAS_VARIABLE(canvasvar_SelectedWaveFormFill, "selected waveform fill")
CANVAS_VARIABLE(canvasvar_SelectedWaveForm, "selected waveform outline")
CANVAS_VARIABLE(canvasvar_SelectionRect, "SelectionRect")
CANVAS_VARIABLE(canvasvar_Selection, "Selection")
CANVAS_VARIABLE(canvasvar_TempoBar, "tempo bar")
CANVAS_VARIABLE(canvasvar_TempoMarker, "TempoMarker")
CANVAS_VARIABLE(canvasvar_TimeAxisFrame, "TimeAxisFrame")
CANVAS_VARIABLE(canvasvar_TimeStretchFill, "time-stretch-fill")
CANVAS_VARIABLE(canvasvar_TimeStretchOutline, "time-stretch-outline")
CANVAS_VARIABLE(canvasvar_TransportDragRect, "TransportDragRect")
CANVAS_VARIABLE(canvasvar_TransportLoopRect, "TransportLoopRect")
CANVAS_VARIABLE(canvasvar_TransportMarkerBar, "TransportMarkerBar")
CANVAS_VARIABLE(canvasvar_TransportPunchRect, "TransportPunchRect")
CANVAS_VARIABLE(canvasvar_TrimHandleLocked, "TrimHandleLocked")
CANVAS_VARIABLE(canvasvar_TrimHandle, "TrimHandle")
CANVAS_VARIABLE(canvasvar_VerboseCanvasCursor, "verbose canvas cursor")
CANVAS_VARIABLE(canvasvar_VestigialFrame, "VestigialFrame")
CANVAS_VARIABLE(canvasvar_WaveFormClip, "clipped waveform")
CANVAS_VARIABLE(canvasvar_WaveFormFill, "waveform fill")
CANVAS_VARIABLE(canvasvar_WaveForm, "waveform outline")
CANVAS_VARIABLE(canvasvar_ZeroLine, "ZeroLine")
CANVAS_VARIABLE(canvasvar_ZoomRect, "ZoomRect")
